@@ -1,5 +1,6 @@
 """Constants for the Dynalite component."""
 import logging
+from typing import Dict, Union
 
 LOGGER = logging.getLogger(__package__)
 DOMAIN = "dynalite-devices"
@@ -28,7 +29,6 @@ CONF_DURATION = "duration"
 CONF_FADE = "fade"
 CONF_HIDDEN_ENTITY = "hidden"
 CONF_HOST = "host"
-CONF_JOIN = "join"
 CONF_NAME = "name"
 CONF_NO_DEFAULT = "nodefault"
 CONF_NONE = "none"
@@ -54,12 +54,12 @@ DEFAULT_CHANNEL_TYPE = "light"
 DEFAULT_COVER_CLASS = "shutter"
 DEFAULT_NAME = "dynalite"
 DEFAULT_PORT = 12345
-DEFAULT_TEMPLATES = {
+DEFAULT_TEMPLATES: Dict[str, Dict[str, Union[str, int]]] = {
     CONF_ROOM: {CONF_ROOM_ON: "1", CONF_ROOM_OFF: "4"},
     CONF_TRIGGER: {CONF_TRIGGER: "1"},
     CONF_HIDDEN_ENTITY: {},
     CONF_TIME_COVER: {
-        CONF_CHANNEL_COVER: "1",
+        CONF_CHANNEL_COVER: "0",
         CONF_DEVICE_CLASS: DEFAULT_COVER_CLASS,
         CONF_OPEN_PRESET: "1",
         CONF_CLOSE_PRESET: "2",
@@ -78,14 +78,5 @@ EVENT_CONNECTED = "CONNECTED"
 EVENT_DISCONNECTED = "DISCONNECTED"
 EVENT_PRESET = "PRESET"
 
-# if a request for channel level didn't get acknowledge, when to retry
-# (subsequent retries will be 2x, 4x, 8x, etc.)
-INITIAL_RETRY_DELAY = 1
-# initial retry timeout for the beginning, since it could take time to settle
-# on Dynet for large environments
-STARTUP_RETRY_DELAY = 60
-# Minimal retry frequency in seconds - default 1 hour, so if something never
-# answers, it will be pinged once an hour XXX consider changing
-MAXIMUM_RETRY_DELAY = 60 * 60
-# no retry value for delay
-NO_RETRY_DELAY_VALUE = -1
+CONNECTION_RETRY_DELAY = 1  # seconds to reconnect
+MESSAGE_DELAY = 0.2  # seconds between sending
